rpms/kernel/FC-4 1748-DRIVER-MODEL-Add-missing-platform_device.h-header.txt, NONE, 1.1.6.1 1761-vmalloc_node.txt, NONE, 1.1.6.1 2468-DRIVER-MODEL-Improved-dynamically-allocated-platform_device-interface.txt, NONE, 1.1.6.1 kernel-2.6.spec, 1.1518.4.1, 1.1518.4.2 1014-Input-convert-net-bluetooth-to-dynamic-input_dev-allocation.txt, 1.1.6.1, NONE 1034-Bluetooth-Move-CRC-table-into-RFCOMM-core.txt, 1.1.6.1, NONE 3166-cris-v10-eth-use-ethtool_ops.txt, 1.1.6.1, NONE 4573-sk98lin-fix-checksumming-code.txt, 1.1.2.1, NONE 4576-sk98lin-allow-ethtool-checksum-on-off-per-port.txt, 1.1.2.1, NONE 4578-sk98lin-remove-proc-interface.txt, 1.1.2.1, NONE

fedora-cvs-commits at redhat.com fedora-cvs-commits at redhat.com
Thu Dec 1 22:44:51 UTC 2005


Author: linville

Update of /cvs/dist/rpms/kernel/FC-4
In directory cvs.devel.redhat.com:/tmp/cvs-serv2856

Modified Files:
      Tag: private-linville-netdev-fc4-4-branch
	kernel-2.6.spec 
Added Files:
      Tag: private-linville-netdev-fc4-4-branch
	1748-DRIVER-MODEL-Add-missing-platform_device.h-header.txt 
	1761-vmalloc_node.txt 
	2468-DRIVER-MODEL-Improved-dynamically-allocated-platform_device-interface.txt 
Removed Files:
      Tag: private-linville-netdev-fc4-4-branch
	1014-Input-convert-net-bluetooth-to-dynamic-input_dev-allocation.txt 
	1034-Bluetooth-Move-CRC-table-into-RFCOMM-core.txt 
	3166-cris-v10-eth-use-ethtool_ops.txt 
	4573-sk98lin-fix-checksumming-code.txt 
	4576-sk98lin-allow-ethtool-checksum-on-off-per-port.txt 
	4578-sk98lin-remove-proc-interface.txt 
Log Message:



--- NEW FILE 1748-DRIVER-MODEL-Add-missing-platform_device.h-header.txt ---
Subject: [PATCH] [DRIVER MODEL] Add missing platform_device.h header.
From: Russell King <rmk at dyn-67.arm.linux.org.uk>
Date: 1130620678 +0100

Signed-off-by: Russell King <rmk+kernel at arm.linux.org.uk>

---

 include/linux/platform_device.h |   40 +++++++++++++++++++++++++++++++++++++++
 1 files changed, 40 insertions(+), 0 deletions(-)
 create mode 100644 include/linux/platform_device.h

applies-to: dac91b70361b405ab8e15207f514a2f3e991e93d
bbbf508d6403f9dfeeb040d9cd7366e395632e59
diff --git a/include/linux/platform_device.h b/include/linux/platform_device.h
new file mode 100644
index 0000000..a726225
--- /dev/null
+++ b/include/linux/platform_device.h
@@ -0,0 +1,40 @@
+/*
+ * platform_device.h - generic, centralized driver model
+ *
+ * Copyright (c) 2001-2003 Patrick Mochel <mochel at osdl.org>
+ *
+ * This file is released under the GPLv2
+ *
+ * See Documentation/driver-model/ for more information.
+ */
+
+#ifndef _PLATFORM_DEVICE_H_
+#define _PLATFORM_DEVICE_H_
+
+#include <linux/device.h>
+
+struct platform_device {
+	const char	* name;
+	u32		id;
+	struct device	dev;
+	u32		num_resources;
+	struct resource	* resource;
+};
+
+#define to_platform_device(x) container_of((x), struct platform_device, dev)
+
+extern int platform_device_register(struct platform_device *);
+extern void platform_device_unregister(struct platform_device *);
+
+extern struct bus_type platform_bus_type;
+extern struct device platform_bus;
+
+extern struct resource *platform_get_resource(struct platform_device *, unsigned int, unsigned int);
+extern int platform_get_irq(struct platform_device *, unsigned int);
+extern struct resource *platform_get_resource_byname(struct platform_device *, unsigned int, char *);
+extern int platform_get_irq_byname(struct platform_device *, char *);
+extern int platform_add_devices(struct platform_device **, int);
+
+extern struct platform_device *platform_device_register_simple(char *, unsigned int, struct resource *, unsigned int);
+
+#endif /* _PLATFORM_DEVICE_H_ */
---
0.99.8.GIT


--- NEW FILE 1761-vmalloc_node.txt ---
Subject: [PATCH] vmalloc_node
From: Christoph Lameter <clameter at engr.sgi.com>
Date: 1130634941 -0700

This patch adds

vmalloc_node(size, node)	-> Allocate necessary memory on the specified node

and

get_vm_area_node(size, flags, node)

and the other functions that it depends on.

Signed-off-by: Andrew Morton <akpm at osdl.org>
Signed-off-by: Linus Torvalds <torvalds at osdl.org>

---

 include/linux/vmalloc.h |    8 +++++
 mm/vmalloc.c            |   73 +++++++++++++++++++++++++++++++++++++----------
 2 files changed, 64 insertions(+), 17 deletions(-)

applies-to: 1a8f95a9960e03149d27d935da25b768878feb3e
930fc45a49ddebe7555cc5c837d82b9c27e65ff4
diff --git a/include/linux/vmalloc.h b/include/linux/vmalloc.h
index 3701a06..1d5577b 100644
--- a/include/linux/vmalloc.h
+++ b/include/linux/vmalloc.h
@@ -32,10 +32,14 @@ struct vm_struct {
  *	Highlevel APIs for driver use
  */
 extern void *vmalloc(unsigned long size);
+extern void *vmalloc_node(unsigned long size, int node);
 extern void *vmalloc_exec(unsigned long size);
 extern void *vmalloc_32(unsigned long size);
 extern void *__vmalloc(unsigned long size, gfp_t gfp_mask, pgprot_t prot);
-extern void *__vmalloc_area(struct vm_struct *area, gfp_t gfp_mask, pgprot_t prot);
+extern void *__vmalloc_area(struct vm_struct *area, gfp_t gfp_mask,
+				pgprot_t prot);
+extern void *__vmalloc_node(unsigned long size, gfp_t gfp_mask,
+				pgprot_t prot, int node);
 extern void vfree(void *addr);
 
 extern void *vmap(struct page **pages, unsigned int count,
@@ -48,6 +52,8 @@ extern void vunmap(void *addr);
 extern struct vm_struct *get_vm_area(unsigned long size, unsigned long flags);
 extern struct vm_struct *__get_vm_area(unsigned long size, unsigned long flags,
 					unsigned long start, unsigned long end);
+extern struct vm_struct *get_vm_area_node(unsigned long size,
+					unsigned long flags, int node);
 extern struct vm_struct *remove_vm_area(void *addr);
 extern struct vm_struct *__remove_vm_area(void *addr);
 extern int map_vm_area(struct vm_struct *area, pgprot_t prot,
diff --git a/drivers/base/platform.c b/drivers/base/platform.c
index d597c92..6d4736e 100644
--- a/drivers/base/platform.c
+++ b/drivers/base/platform.c
@@ -116,12 +116,115 @@ int platform_add_devices(struct platform
 	return ret;
 }
 
+struct platform_object {
+	struct platform_device pdev;
+	char name[1];
+};
+
 /**
- *	platform_device_register - add a platform-level device
+ *	platform_device_put
+ *	@pdev:	platform device to free
+ *
+ *	Free all memory associated with a platform device.  This function
+ *	must _only_ be externally called in error cases.  All other usage
+ *	is a bug.
+ */
+void platform_device_put(struct platform_device *pdev)
+{
+	if (pdev)
+		put_device(&pdev->dev);
+}
+EXPORT_SYMBOL_GPL(platform_device_put);
+
+static void platform_device_release(struct device *dev)
+{
+	struct platform_object *pa = container_of(dev, struct platform_object, pdev.dev);
+
+	kfree(pa->pdev.dev.platform_data);
+	kfree(pa->pdev.resource);
+	kfree(pa);
+}
+
+/**
+ *	platform_device_alloc
+ *	@name:	base name of the device we're adding
+ *	@id:    instance id
+ *
+ *	Create a platform device object which can have other objects attached
+ *	to it, and which will have attached objects freed when it is released.
+ */
+struct platform_device *platform_device_alloc(const char *name, unsigned int id)
+{
+	struct platform_object *pa;
+
+	pa = kzalloc(sizeof(struct platform_object) + strlen(name), GFP_KERNEL);
+	if (pa) {
+		strcpy(pa->name, name);
+		pa->pdev.name = pa->name;
+		pa->pdev.id = id;
+		device_initialize(&pa->pdev.dev);
+		pa->pdev.dev.release = platform_device_release;
+	}
+
+	return pa ? &pa->pdev : NULL;	
+}
+EXPORT_SYMBOL_GPL(platform_device_alloc);
+
+/**
+ *	platform_device_add_resources
+ *	@pdev:	platform device allocated by platform_device_alloc to add resources to
+ *	@res:   set of resources that needs to be allocated for the device
+ *	@num:	number of resources
+ *
+ *	Add a copy of the resources to the platform device.  The memory
+ *	associated with the resources will be freed when the platform
+ *	device is released.
+ */
+int platform_device_add_resources(struct platform_device *pdev, struct resource *res, unsigned int num)
+{
+	struct resource *r;
+
+	r = kmalloc(sizeof(struct resource) * num, GFP_KERNEL);
+	if (r) {
+		memcpy(r, res, sizeof(struct resource) * num);
+		pdev->resource = r;
+		pdev->num_resources = num;
+	}
+	return r ? 0 : -ENOMEM;
+}
+EXPORT_SYMBOL_GPL(platform_device_add_resources);
+
+/**
+ *	platform_device_add_data
+ *	@pdev:	platform device allocated by platform_device_alloc to add resources to
+ *	@data:	platform specific data for this platform device
+ *	@size:	size of platform specific data
+ *
+ *	Add a copy of platform specific data to the platform device's platform_data
+ *	pointer.  The memory associated with the platform data will be freed
+ *	when the platform device is released.
+ */
+int platform_device_add_data(struct platform_device *pdev, void *data, size_t size)
+{
+	void *d;
+
+	d = kmalloc(size, GFP_KERNEL);
+	if (d) {
+		memcpy(d, data, size);
+		pdev->dev.platform_data = d;
+	}
+	return d ? 0 : -ENOMEM;
+}
+EXPORT_SYMBOL_GPL(platform_device_add_data);
+
+/**
+ *	platform_device_add - add a platform device to device hierarchy
  *	@pdev:	platform device we're adding
  *
+ *	This is part 2 of platform_device_register(), though may be called
+ *	separately _iff_ pdev was allocated by platform_device_alloc().
  */
-int platform_device_register(struct platform_device * pdev)
+int platform_device_add(struct platform_device *pdev)
 {
 	int i, ret = 0;
 
@@ -174,6 +277,18 @@ int platform_device_register(struct plat
 			release_resource(&pdev->resource[i]);
 	return ret;
 }
+EXPORT_SYMBOL_GPL(platform_device_add);
+
+/**
+ *	platform_device_register - add a platform-level device
+ *	@pdev:	platform device we're adding
+ *
+ */
+int platform_device_register(struct platform_device * pdev)
+{
+	device_initialize(&pdev->dev);
+	return platform_device_add(pdev);
+}
 
 /**
  *	platform_device_unregister - remove a platform-level device
@@ -197,18 +312,6 @@ void platform_device_unregister(struct p
 	}
 }
 
-struct platform_object {
-        struct platform_device pdev;
-        struct resource resources[0];
-};
-
-static void platform_device_release_simple(struct device *dev)
-{
-	struct platform_device *pdev = to_platform_device(dev);
-
-	kfree(container_of(pdev, struct platform_object, pdev));
-}
-
 /**
  *	platform_device_register_simple
  *	@name:  base name of the device we're adding
@@ -225,33 +328,29 @@ static void platform_device_release_simp
 struct platform_device *platform_device_register_simple(char *name, unsigned int id,
 							struct resource *res, unsigned int num)
 {
-	struct platform_object *pobj;
+	struct platform_device *pdev;
 	int retval;
 
-	pobj = kzalloc(sizeof(*pobj) + sizeof(struct resource) * num, GFP_KERNEL);
-	if (!pobj) {
+	pdev = platform_device_alloc(name, id);
+	if (!pdev) {
 		retval = -ENOMEM;
 		goto error;
 	}
 
-	pobj->pdev.name = name;
-	pobj->pdev.id = id;
-	pobj->pdev.dev.release = platform_device_release_simple;
-
 	if (num) {
-		memcpy(pobj->resources, res, sizeof(struct resource) * num);
-		pobj->pdev.resource = pobj->resources;
-		pobj->pdev.num_resources = num;
+		retval = platform_device_add_resources(pdev, res, num);
+		if (retval)
+			goto error;
 	}
 
-	retval = platform_device_register(&pobj->pdev);
+	retval = platform_device_add(pdev);
 	if (retval)
 		goto error;
 
-	return &pobj->pdev;
+	return pdev;
 
 error:
-	kfree(pobj);
+	platform_device_put(pdev);
 	return ERR_PTR(retval);
 }
 
diff --git a/include/linux/platform_device.h b/include/linux/platform_device.h
index a726225..1a165b7 100644
--- a/include/linux/platform_device.h
+++ b/include/linux/platform_device.h
@@ -37,4 +37,10 @@ extern int platform_add_devices(struct p
 
 extern struct platform_device *platform_device_register_simple(char *, unsigned int, struct resource *, unsigned int);
 
+extern struct platform_device *platform_device_alloc(const char *name, unsigned int id);
+extern int platform_device_add_resources(struct platform_device *pdev, struct resource *res, unsigned int num);
+extern int platform_device_add_data(struct platform_device *pdev, void *data, size_t size);
+extern int platform_device_add(struct platform_device *pdev);
+extern void platform_device_put(struct platform_device *pdev);
+
 #endif /* _PLATFORM_DEVICE_H_ */
---
0.99.8.GIT


Index: kernel-2.6.spec
===================================================================
RCS file: /cvs/dist/rpms/kernel/FC-4/kernel-2.6.spec,v
retrieving revision 1.1518.4.1
retrieving revision 1.1518.4.2
diff -u -r1.1518.4.1 -r1.1518.4.2
--- kernel-2.6.spec	1 Dec 2005 18:06:06 -0000	1.1518.4.1
+++ kernel-2.6.spec	1 Dec 2005 22:44:49 -0000	1.1518.4.2
@@ -605,59 +605,59 @@
 Patch20230: 0973-sky2-spelling-fixes.txt
 Patch20231: 0974-sky2-fix-NAPI-and-receive-handling.txt
 Patch20232: 0975-sky2-version-0.7.txt
-Patch20233: 1014-Input-convert-net-bluetooth-to-dynamic-input_dev-allocation.txt
-Patch20234: 1029-DRIVER-MODEL-Get-rid-of-the-obsolete-tri-level-suspend-resume-callbacks.txt
-Patch20235: 1034-Bluetooth-Move-CRC-table-into-RFCOMM-core.txt
-Patch20236: 1037-Bluetooth-Make-more-functions-static.txt
-Patch20237: 1038-Bluetooth-Update-security-filter-for-Extended-Inquiry-Response.txt
-Patch20238: 1043-IPv4-IPv6-UFO-Scatter-gather-approach.txt
-Patch20239: 1044-MCAST-IPv6-Fix-algorithm-to-compute-Querier-s-Query-Interval.txt
-Patch20240: 1055-tg3-add-5714-5715-support.txt
-Patch20241: 1056-tg3-fix-ASF-heartbeat.txt
-Patch20242: 1057-tg3-update-version-and-minor-fixes.txt
-Patch20243: 1058-ibmveth-fix-bonding.txt
-Patch20244: 1059-ibmveth-fix-buffer-pool-management.txt
-Patch20245: 1060-ibmveth-fix-buffer-replenishing.txt
-Patch20246: 1061-ibmveth-lockless-TX.txt
-Patch20247: 1062-ibmveth-fix-failed-addbuf.txt
-Patch20248: 1063-pcnet_cs-fix-mii-init-code-for-older-DL10019-based-cards.txt
-Patch20249: 1065-s2io-kconfig-help-fix.txt
-Patch20250: 1066-b44-reports-wrong-advertised-flags.txt
-Patch20251: 1067-sis190.c-fix-multicast-MAC-filter.txt
-Patch20252: 1068-smc91x-shut-down-power-after-probing.txt
-Patch20253: 1070-starfire-free_irq-on-error-path-of-netdev_open.txt
-Patch20254: 1073-netdrvr-b44-include-linux-dma-mapping.h-to-eliminate-warning.txt
-Patch20255: 1074-sundance-fix-DFE-580TX-Tx-Underrun.txt
-Patch20256: 1075-New-PowerPC-4xx-on-chip-ethernet-controller-driver.txt
-Patch20257: 1078-sis900-come-alive-after-temporary-memory-shortage.txt
-Patch20258: 1079-Add-Wake-on-LAN-support-to-sis900-2.txt
-Patch20259: 1080-drivers-net-Remove-pointless-checks-for-NULL-prior-to-calling-kfree.txt
-Patch20260: 1082-netdrvr-ne2k-pci-based-card-does-not-support-bus-mastering.txt
-Patch20261: 1083-ipw2200-Missing-kmalloc-check.txt
-Patch20262: 1159-SCTP-Rename-SCTP-specific-control-message-flags.txt
-Patch20263: 1163-SCTP-Fix-SCTP_SETADAPTION-sockopt-to-use-the-correct-structure.txt
-Patch20264: 1164-SCTP-Allow-SCTP_MAXSEG-to-revert-to-default-frag-point-with-a-0-value.txt
-Patch20265: 1196-SCTP-Do-not-allow-unprivileged-programs-initiating-new-associations-on.txt
-Patch20266: 1200-e1000-remove-warning-about-e1000_suspend.txt
-Patch20267: 1201-eepro.c-module_param_array-cleanup.txt
-Patch20268: 1202-b44-fix-suspend-resume.txt
-Patch20269: 1203-e1000-use-vmalloc_node.txt
-Patch20270: 1204-revert-orinoco-Information-leakage-due-to-incorrect-padding.txt
-Patch20271: 1205-Better-fixup-for-the-orinoco-driver.txt
-Patch20272: 1206-e1000-Fixes-e1000_suspend-warning-when-CONFIG_PM-is-not-enabled.txt
-Patch20273: 1320-ETH-ether-address-compare.txt
-Patch20274: 1324-Add-modalias-for-pmac-network-drivers.txt
-Patch20275: 1328-mv643xx_eth_showsram-Added-information-message-when-using-the-SRAM.txt
-Patch20276: 1329-IPV4-Fix-issue-reported-by-Coverity-in-ipv4-fib_frontend.c.txt
-Patch20277: 1389-s2io-iomem-annotations.txt
-Patch20278: 1397-bluetooth-hidp-is-broken-on-s390.txt
-Patch20279: 1403-drivers-net-tg3-Use-the-DMA_-32-64-BIT_MASK-constants.txt
-Patch20280: 1405-prism54-Free-skb-after-disabling-interrupts.txt
-Patch20281: 1749-PPC-44x-EMAC-driver-add-440SPe-support.txt
-Patch20282: 1750-PPC-44x-EMAC-driver-add-440GR-support.txt
-Patch20283: 1751-PPC-4xx-EMAC-driver-fix-VSC8201-PHY-initialization.txt
-Patch20284: 1754-fec_8xx-Remove-dependency-on-NETTA-NETPHONE.txt
-Patch20285: 1755-fec_8xx-Add-support-for-Intel-PHY-LX971.txt
+Patch20233: 1029-DRIVER-MODEL-Get-rid-of-the-obsolete-tri-level-suspend-resume-callbacks.txt
+Patch20234: 1037-Bluetooth-Make-more-functions-static.txt
+Patch20235: 1038-Bluetooth-Update-security-filter-for-Extended-Inquiry-Response.txt
+Patch20236: 1043-IPv4-IPv6-UFO-Scatter-gather-approach.txt
+Patch20237: 1044-MCAST-IPv6-Fix-algorithm-to-compute-Querier-s-Query-Interval.txt
+Patch20238: 1055-tg3-add-5714-5715-support.txt
+Patch20239: 1056-tg3-fix-ASF-heartbeat.txt
+Patch20240: 1057-tg3-update-version-and-minor-fixes.txt
+Patch20241: 1058-ibmveth-fix-bonding.txt
+Patch20242: 1059-ibmveth-fix-buffer-pool-management.txt
+Patch20243: 1060-ibmveth-fix-buffer-replenishing.txt
+Patch20244: 1061-ibmveth-lockless-TX.txt
+Patch20245: 1062-ibmveth-fix-failed-addbuf.txt
+Patch20246: 1063-pcnet_cs-fix-mii-init-code-for-older-DL10019-based-cards.txt
+Patch20247: 1065-s2io-kconfig-help-fix.txt
+Patch20248: 1066-b44-reports-wrong-advertised-flags.txt
+Patch20249: 1067-sis190.c-fix-multicast-MAC-filter.txt
+Patch20250: 1068-smc91x-shut-down-power-after-probing.txt
+Patch20251: 1070-starfire-free_irq-on-error-path-of-netdev_open.txt
+Patch20252: 1073-netdrvr-b44-include-linux-dma-mapping.h-to-eliminate-warning.txt
+Patch20253: 1074-sundance-fix-DFE-580TX-Tx-Underrun.txt
+Patch20254: 1075-New-PowerPC-4xx-on-chip-ethernet-controller-driver.txt
+Patch20255: 1078-sis900-come-alive-after-temporary-memory-shortage.txt
+Patch20256: 1079-Add-Wake-on-LAN-support-to-sis900-2.txt
+Patch20257: 1080-drivers-net-Remove-pointless-checks-for-NULL-prior-to-calling-kfree.txt
+Patch20258: 1082-netdrvr-ne2k-pci-based-card-does-not-support-bus-mastering.txt
+Patch20259: 1083-ipw2200-Missing-kmalloc-check.txt
+Patch20260: 1159-SCTP-Rename-SCTP-specific-control-message-flags.txt
+Patch20261: 1163-SCTP-Fix-SCTP_SETADAPTION-sockopt-to-use-the-correct-structure.txt
+Patch20262: 1164-SCTP-Allow-SCTP_MAXSEG-to-revert-to-default-frag-point-with-a-0-value.txt
+Patch20263: 1196-SCTP-Do-not-allow-unprivileged-programs-initiating-new-associations-on.txt
+Patch20264: 1200-e1000-remove-warning-about-e1000_suspend.txt
+Patch20265: 1201-eepro.c-module_param_array-cleanup.txt
+Patch20266: 1202-b44-fix-suspend-resume.txt
+Patch20267: 1203-e1000-use-vmalloc_node.txt
+Patch20268: 1204-revert-orinoco-Information-leakage-due-to-incorrect-padding.txt
+Patch20269: 1205-Better-fixup-for-the-orinoco-driver.txt
+Patch20270: 1206-e1000-Fixes-e1000_suspend-warning-when-CONFIG_PM-is-not-enabled.txt
+Patch20271: 1320-ETH-ether-address-compare.txt
+Patch20272: 1324-Add-modalias-for-pmac-network-drivers.txt
+Patch20273: 1328-mv643xx_eth_showsram-Added-information-message-when-using-the-SRAM.txt
+Patch20274: 1329-IPV4-Fix-issue-reported-by-Coverity-in-ipv4-fib_frontend.c.txt
+Patch20275: 1389-s2io-iomem-annotations.txt
+Patch20276: 1397-bluetooth-hidp-is-broken-on-s390.txt
+Patch20277: 1403-drivers-net-tg3-Use-the-DMA_-32-64-BIT_MASK-constants.txt
+Patch20278: 1405-prism54-Free-skb-after-disabling-interrupts.txt
+Patch20279: 1748-DRIVER-MODEL-Add-missing-platform_device.h-header.txt
+Patch20280: 1749-PPC-44x-EMAC-driver-add-440SPe-support.txt
+Patch20281: 1750-PPC-44x-EMAC-driver-add-440GR-support.txt
+Patch20282: 1751-PPC-4xx-EMAC-driver-fix-VSC8201-PHY-initialization.txt
+Patch20283: 1754-fec_8xx-Remove-dependency-on-NETTA-NETPHONE.txt
+Patch20284: 1755-fec_8xx-Add-support-for-Intel-PHY-LX971.txt
+Patch20285: 1761-vmalloc_node.txt
 Patch20286: 1854-ARM-3066-1-Fix-PXA-irda-driver-suspend-resume-functions.txt
 Patch20287: 1920-m32r-SMC91x-driver-update.txt
 Patch20288: 1929-smsc-ircc2-PM-cleanup-do-not-close-device-when-suspending.txt
@@ -718,138 +718,138 @@
 Patch20343: 2465-PKT_SCHED-GRED-Fix-restart-of-idle-period-in-WRED-mode-upon-dequeue-and-drop.txt
 Patch20344: 2466-PKT_SCHED-GRED-Support-ECN-marking.txt
 Patch20345: 2467-PKT_SCHED-G-RED-Introduce-hard-dropping.txt
-Patch20346: 2469-DRIVER-MODEL-Fix-depca.txt
-Patch20347: 2470-DRIVER-MODEL-Fix-jazzsonic.txt
-Patch20348: 2471-DRIVER-MODEL-Fix-macsonic.txt
-Patch20349: 2476-NETEM-Support-time-based-reordering.txt
-Patch20350: 2477-NETEM-Add-version-string.txt
-Patch20351: 2478-NET-Fix-race-condition-in-sk_stream_wait_connect.txt
-Patch20352: 2479-TCP-DCCP-Randomize-port-selection.txt
-Patch20353: 2481-drivers-net-ixgb-make-some-code-static.txt
-Patch20354: 2482-drivers-net-e1000-possible-cleanups.txt
-Patch20355: 2483-drivers-net-hamradio-dmascc.c-remove-dmascc_setup.txt
-Patch20356: 2484-prism54-Remove-redundant-assignment.txt
-Patch20357: 2485-bnx2-add-5708-support.txt
-Patch20358: 2486-bnx2-update-firmware-for-5708.txt
-Patch20359: 2487-bnx2-update-nvram-code-for-5708.txt
-Patch20360: 2488-bnx2-update-firmware-handshake-for-5708.txt
-Patch20361: 2489-bnx2-refine-bnx2_poll.txt
-Patch20362: 2490-bnx2-update-version-and-minor-fixes.txt
-Patch20363: 2493-Remove-linux-version.h-include-from-drivers-net-phy-and-net-ieee80211.txt
-Patch20364: 2494-netdrvr-fac_8xx-build-fix.txt
-Patch20365: 2495-netdrvr-s2io-warning-fixes.txt
-Patch20366: 2645-b44-b44_start_xmit-returns-with-a-lock-held-when-it-fails-allocating.txt
-Patch20367: 2646-b44-miscellaneous-cleanup.txt
-Patch20368: 2647-b44-expose-counters-through-ethtool.txt
-Patch20369: 2648-b44-s-spin_lock_irqsave-spin_lock-in-b44_interrupt.txt
-Patch20370: 2649-b44-late-request_irq-in-b44_open.txt
-Patch20371: 2681-3c59x-convert-to-use-of-pci_iomap-API.txt
-Patch20372: 2682-3c59x-cleanup-of-mdio_read-routines-to-use-MII_-macros.txt
-Patch20373: 2683-3c59x-avoid-blindly-reading-link-status-twice.txt
-Patch20374: 2684-3c59x-bounds-checking-for-hw_checksums.txt
-Patch20375: 2685-3c59x-cleanup-init-of-module-parameter-arrays.txt
-Patch20376: 2686-3c59x-fix-some-grammar-in-module-parameter-descriptions.txt
-Patch20377: 2687-3c59x-support-ETHTOOL_GPERMADDR.txt
-Patch20378: 2688-3c59x-correct-rx_dropped-counting.txt
-Patch20379: 2689-3c59x-enable-use-of-memory-mapped-PCI-I-O.txt
-Patch20380: 2690-3c59x-don-t-enable-scatter-gather-w-o-checksum-support.txt
-Patch20381: 2821-knfsd-make-sure-svc_process-call-the-correct-pg_authenticate-for-multi-service-port.txt
-Patch20382: 2927-m68knommu-FEC-ethernet-header-support-for-the-ColdFire-5208.txt
-Patch20383: 2928-m68knommu-FEC-ethernet-support-for-the-ColdFire-5208.txt
-Patch20384: 2977-scripts-Lindent-on-ieee80211-subsystem.txt
-Patch20385: 2978-Fix-problem-with-WEP-unicast-key-index-0.txt
-Patch20386: 2979-Update-version-ieee80211-stamp-to-1.1.7.txt
-Patch20387: 2980-Ran-scripts-Lindent-on-drivers-net-wireless-ipw2-1-2-00.-c-h.txt
-Patch20388: 2981-IPW_DEBUG-has-already-included-DRV_NAME-remove-double-prefix-print.txt
-Patch20389: 2982-Catch-ipw2200-up-to-equivelancy-with-v1.0.1.txt
-Patch20390: 2983-Catch-ipw2200-up-to-equivelancy-with-v1.0.2.txt
-Patch20391: 2984-Catch-ipw2200-up-to-equivelancy-with-v1.0.3.txt
-Patch20392: 2985-Catch-ipw2200-up-to-equivelancy-with-v1.0.4.txt
-Patch20393: 2986-Catch-ipw2100-up-to-equivelancy-with-v1.1.1.txt
-Patch20394: 2987-Fixed-WEP-on-ipw2100-priv-sec-was-being-used-instead-of.txt
-Patch20395: 2988-Bug-339-Fix-ipw2100-iwconfig-set-get-txpower.txt
-Patch20396: 2989-Move-code-from-ipw2100_wpa_enable-to-IPW2100_PARAM_DROP_UNENCRYPTED-to.txt
-Patch20397: 2990-Catch-ipw2200-up-to-equivelancy-with-v1.0.5.txt
-Patch20398: 2991-Fix-hardware-encryption-both-WEP-and-AES-doesn-t-work-with-fragmentation.txt
-Patch20399: 2992-Fix-is_duplicate_packet-bug-for-fragmentation-number-setting.txt
-Patch20400: 2993-bug-667-Fix-the-notorious-No-space-for-Tx-bug.txt
-Patch20401: 2994-Bug-637-Set-tx-power-for-A-band.txt
-Patch20402: 2995-Changed-default-of-missed-beacons-to-miss-before-disassociation-to-24.txt
-Patch20403: 2996-Updated-to-support-ieee80211-callback-to-is_queue_full-for-802.11e.txt
-Patch20404: 2997-Fixed-some-compiler-issues-if-CONFIG_IPW2200_QOS-is-enabled.txt
-Patch20405: 2998-Added-more-useful-geography-encoding-so-people-s-experience-with.txt
-Patch20406: 2999-Workaround-kernel-BUG_ON-panic-caused-by-unexpected-duplicate-packets.txt
-Patch20407: 3000-Disable-host-fragmentation-in-open-mode-since-IPW2200-2915-hardware.txt
-Patch20408: 3001-Bug-792-Fix-WPA-PSK-AES-both-for-Dipw-and-Dwext.txt
-Patch20409: 3002-Fixes-the-ad-hoc-network-WEP-key-list-issue.txt
-Patch20410: 3003-Bug-701-Fix-a-misuse-of-ieee-mode-with-ieee-iw_mode.txt
-Patch20411: 3004-Fix-ipw_wx_get_txpow-shows-wrong-disabled-value.txt
-Patch20412: 3005-Fix-firmware-error-when-setting-tx_power.txt
-Patch20413: 3006-Modified-ipw_config-and-STATUS_INIT-setting-to-correct-race-condition.txt
-Patch20414: 3007-Switched-firmware-error-dumping-so-that-it-will-capture-a-log-available.txt
-Patch20415: 3008-Changed-all-of-the-ipw_send_cmd-calls-to-return-any-ipw_send_cmd-error.txt
-Patch20416: 3009-Added-cmdlog-in-non-debug-systems.txt
-Patch20417: 3010-Migrated-some-of-the-channel-verification-code-back-into-the-driver-to.txt
-Patch20418: 3011-Updated-ipw2200-to-use-the-new-ieee80211-callbacks.txt
-Patch20419: 3012-Added-wait_state-wakeup-on-scan-completion.txt
-Patch20420: 3013-Bug-455-Fix-frequent-channel-change-generates-firmware-fatal-error.txt
-Patch20421: 3014-Bug-760-Fix-setting-WEP-key-in-monitor-mode-causes-IV-lost.txt
-Patch20422: 3015-Don-t-set-hardware-WEP-if-we-are-actually-using-TKIP-AES.txt
-Patch20423: 3016-Make-all-the-places-the-firmware-fails-to-load-showerrors-in-decimal.txt
-Patch20424: 3017-Adds-radiotap-support-to-ipw2200-in-monitor-mode.txt
-Patch20425: 3018-Fixed-is_network_packet-to-include-checking-for-broadcast-packets.txt
-Patch20426: 3019-Mixed-PTK-GTK-CCMP-TKIP-support.txt
-Patch20427: 3020-Card-with-WEP-enabled-and-using-shared-key-auth-will-have-firmware.txt
-Patch20428: 3021-Fixed-problem-with-get_cmd_string-not-existing-if-CONFIG_IPW_DEBUG-disabled.txt
-Patch20429: 3022-Removed-PF_SYNCTHREAD-legacy.txt
-Patch20430: 3023-Fixes-problem-with-WEP-not-working-association-succeeds-but-no-Tx-Rx.txt
-Patch20431: 3024-Fix-bug-771-Too-many-8-bytes-recieved-when-using-AES-hwcrypto.txt
-Patch20432: 3025-Fixes-WEP-firmware-error-condition.txt
-Patch20433: 3026-Updated-driver-version-stamps-for-ipw2100-1.1.3-and-ipw2200-1.0.7.txt
-Patch20434: 3027-Pulled-out-a-stray-KERNEL_VERSION-check-around-the-suspend-handler.txt
-Patch20435: 3028-Fix-Driver-using-old-proc-net-wireless-support-please-fix-driver-message.txt
-Patch20436: 3029-Removed-legacy-WIRELESS_EXT-checks-from-ipw2200.c.txt
-Patch20437: 3030-Fixes-missed-beacon-logic-in-relation-to-on-network-AP-roaming.txt
-Patch20438: 3031-Removed-warning-about-TKIP-not-being-configured-if-countermeasures-are.txt
-Patch20439: 3032-Added-channel-support-for-ipw2200-cards-identified-as-ZZR.txt
-Patch20440: 3033-Fixed-problem-with-not-being-able-to-send-broadcast-packets.txt
-Patch20441: 3034-Fixed-parameter-reordering-in-firmware-log-routine.txt
-Patch20442: 3035-Updated-firmware-version-stamp-to-2.4-from-2.3-so-it-will-use-the-latest-firmware.txt
-Patch20443: 3036-Update-version-ipw2200-stamp-to-1.0.8.txt
-Patch20444: 3074-fix-NET_RADIO-n-IEEE80211-y-compile.txt
-Patch20445: 3075-bonding-fix-feature-consolidation.txt
-Patch20446: 3076-kill-include-linux-eeprom.h.txt
-Patch20447: 3077-drivers-net-s2io.c-make-functions-static.txt
-Patch20448: 3078-prism54-Unused-variable-extraneous-udelay.txt
-Patch20449: 3079-prism54-Transmit-stats-updated-in-wrong-place.txt
-Patch20450: 3080-Fix-sparse-warning-in-e100-driver.txt
-Patch20451: 3081-atmel-memset-correct-range.txt
-Patch20452: 3110-IPV6-Put-addr_diff-into-common-header-for-future-use.txt
-Patch20453: 3111-IPV6-Make-ipv6_addr_type-more-generic-so-that-we-can-use-it-for-source-address-selection.txt
-Patch20454: 3112-IPV6-RFC3484-compliant-source-address-selection.txt
-Patch20455: 3114-PKT_SCHED-Correctly-handle-empty-ematch-trees.txt
-Patch20456: 3115-NET-sk_add_backlog-convert-from-macro-to-inline.txt
-Patch20457: 3117-PPP-handle-misaligned-accesses.txt
-Patch20458: 3118-PPP-add-PPP-MPPE-encryption-module.txt
-Patch20459: 3119-IRDA-donauboe-locking-fix.txt
-Patch20460: 3120-NET-kfree-cleanup.txt
-Patch20461: 3121-IPV4-Fix-ip_queue_xmit-identity-increment-for-TSO-packets.txt
-Patch20462: 3124-Bluetooth-Add-endian-annotations-to-the-core.txt
-Patch20463: 3125-Bluetooth-Remove-the-usage-of-proc-completely.txt
-Patch20464: 3148-SERIAL-IOC3-Update-8250-driver-bits.txt
-Patch20465: 3153-skge-clear-PCI-PHY-COMA-mode-on-boot.txt
-Patch20466: 3154-skge-use-kzalloc.txt
-Patch20467: 3155-skge-add-mii-ioctl-support.txt
-Patch20468: 3156-skge-goto-low-power-mode-on-shutdown.txt
-Patch20469: 3157-skge-use-prefetch-on-receive.txt
-Patch20470: 3158-skge-spelling-fixes.txt
-Patch20471: 3159-skge-increase-version-number.txt
-Patch20472: 3161-wireless-ipw2100-kill-unused-var-warnings-for-debug-disabled-code.txt
-Patch20473: 3162-ieee80211-cleanup-crypto-list-handling-other-minor-cleanups.txt
-Patch20474: 3163-b44-replace-B44_FLAG_INIT_COMPLETE-with-netif_running.txt
-Patch20475: 3164-b44-race-on-device-closing.txt
-Patch20476: 3165-b44-increase-version-number.txt
-Patch20477: 3166-cris-v10-eth-use-ethtool_ops.txt
+Patch20346: 2468-DRIVER-MODEL-Improved-dynamically-allocated-platform_device-interface.txt
+Patch20347: 2469-DRIVER-MODEL-Fix-depca.txt
+Patch20348: 2470-DRIVER-MODEL-Fix-jazzsonic.txt
+Patch20349: 2471-DRIVER-MODEL-Fix-macsonic.txt
+Patch20350: 2476-NETEM-Support-time-based-reordering.txt
+Patch20351: 2477-NETEM-Add-version-string.txt
+Patch20352: 2478-NET-Fix-race-condition-in-sk_stream_wait_connect.txt
+Patch20353: 2479-TCP-DCCP-Randomize-port-selection.txt
+Patch20354: 2481-drivers-net-ixgb-make-some-code-static.txt
+Patch20355: 2482-drivers-net-e1000-possible-cleanups.txt
+Patch20356: 2483-drivers-net-hamradio-dmascc.c-remove-dmascc_setup.txt
+Patch20357: 2484-prism54-Remove-redundant-assignment.txt
+Patch20358: 2485-bnx2-add-5708-support.txt
+Patch20359: 2486-bnx2-update-firmware-for-5708.txt
+Patch20360: 2487-bnx2-update-nvram-code-for-5708.txt
+Patch20361: 2488-bnx2-update-firmware-handshake-for-5708.txt
+Patch20362: 2489-bnx2-refine-bnx2_poll.txt
+Patch20363: 2490-bnx2-update-version-and-minor-fixes.txt
+Patch20364: 2493-Remove-linux-version.h-include-from-drivers-net-phy-and-net-ieee80211.txt
+Patch20365: 2494-netdrvr-fac_8xx-build-fix.txt
+Patch20366: 2495-netdrvr-s2io-warning-fixes.txt
+Patch20367: 2645-b44-b44_start_xmit-returns-with-a-lock-held-when-it-fails-allocating.txt
+Patch20368: 2646-b44-miscellaneous-cleanup.txt
+Patch20369: 2647-b44-expose-counters-through-ethtool.txt
+Patch20370: 2648-b44-s-spin_lock_irqsave-spin_lock-in-b44_interrupt.txt
+Patch20371: 2649-b44-late-request_irq-in-b44_open.txt
+Patch20372: 2681-3c59x-convert-to-use-of-pci_iomap-API.txt
+Patch20373: 2682-3c59x-cleanup-of-mdio_read-routines-to-use-MII_-macros.txt
+Patch20374: 2683-3c59x-avoid-blindly-reading-link-status-twice.txt
+Patch20375: 2684-3c59x-bounds-checking-for-hw_checksums.txt
+Patch20376: 2685-3c59x-cleanup-init-of-module-parameter-arrays.txt
+Patch20377: 2686-3c59x-fix-some-grammar-in-module-parameter-descriptions.txt
+Patch20378: 2687-3c59x-support-ETHTOOL_GPERMADDR.txt
+Patch20379: 2688-3c59x-correct-rx_dropped-counting.txt
+Patch20380: 2689-3c59x-enable-use-of-memory-mapped-PCI-I-O.txt
+Patch20381: 2690-3c59x-don-t-enable-scatter-gather-w-o-checksum-support.txt
+Patch20382: 2821-knfsd-make-sure-svc_process-call-the-correct-pg_authenticate-for-multi-service-port.txt
+Patch20383: 2927-m68knommu-FEC-ethernet-header-support-for-the-ColdFire-5208.txt
+Patch20384: 2928-m68knommu-FEC-ethernet-support-for-the-ColdFire-5208.txt
+Patch20385: 2977-scripts-Lindent-on-ieee80211-subsystem.txt
+Patch20386: 2978-Fix-problem-with-WEP-unicast-key-index-0.txt
+Patch20387: 2979-Update-version-ieee80211-stamp-to-1.1.7.txt
+Patch20388: 2980-Ran-scripts-Lindent-on-drivers-net-wireless-ipw2-1-2-00.-c-h.txt
+Patch20389: 2981-IPW_DEBUG-has-already-included-DRV_NAME-remove-double-prefix-print.txt
+Patch20390: 2982-Catch-ipw2200-up-to-equivelancy-with-v1.0.1.txt
+Patch20391: 2983-Catch-ipw2200-up-to-equivelancy-with-v1.0.2.txt
+Patch20392: 2984-Catch-ipw2200-up-to-equivelancy-with-v1.0.3.txt
+Patch20393: 2985-Catch-ipw2200-up-to-equivelancy-with-v1.0.4.txt
+Patch20394: 2986-Catch-ipw2100-up-to-equivelancy-with-v1.1.1.txt
+Patch20395: 2987-Fixed-WEP-on-ipw2100-priv-sec-was-being-used-instead-of.txt
+Patch20396: 2988-Bug-339-Fix-ipw2100-iwconfig-set-get-txpower.txt
+Patch20397: 2989-Move-code-from-ipw2100_wpa_enable-to-IPW2100_PARAM_DROP_UNENCRYPTED-to.txt
+Patch20398: 2990-Catch-ipw2200-up-to-equivelancy-with-v1.0.5.txt
+Patch20399: 2991-Fix-hardware-encryption-both-WEP-and-AES-doesn-t-work-with-fragmentation.txt
+Patch20400: 2992-Fix-is_duplicate_packet-bug-for-fragmentation-number-setting.txt
+Patch20401: 2993-bug-667-Fix-the-notorious-No-space-for-Tx-bug.txt
+Patch20402: 2994-Bug-637-Set-tx-power-for-A-band.txt
+Patch20403: 2995-Changed-default-of-missed-beacons-to-miss-before-disassociation-to-24.txt
+Patch20404: 2996-Updated-to-support-ieee80211-callback-to-is_queue_full-for-802.11e.txt
+Patch20405: 2997-Fixed-some-compiler-issues-if-CONFIG_IPW2200_QOS-is-enabled.txt
+Patch20406: 2998-Added-more-useful-geography-encoding-so-people-s-experience-with.txt
+Patch20407: 2999-Workaround-kernel-BUG_ON-panic-caused-by-unexpected-duplicate-packets.txt
+Patch20408: 3000-Disable-host-fragmentation-in-open-mode-since-IPW2200-2915-hardware.txt
+Patch20409: 3001-Bug-792-Fix-WPA-PSK-AES-both-for-Dipw-and-Dwext.txt
+Patch20410: 3002-Fixes-the-ad-hoc-network-WEP-key-list-issue.txt
+Patch20411: 3003-Bug-701-Fix-a-misuse-of-ieee-mode-with-ieee-iw_mode.txt
+Patch20412: 3004-Fix-ipw_wx_get_txpow-shows-wrong-disabled-value.txt
+Patch20413: 3005-Fix-firmware-error-when-setting-tx_power.txt
+Patch20414: 3006-Modified-ipw_config-and-STATUS_INIT-setting-to-correct-race-condition.txt
+Patch20415: 3007-Switched-firmware-error-dumping-so-that-it-will-capture-a-log-available.txt
+Patch20416: 3008-Changed-all-of-the-ipw_send_cmd-calls-to-return-any-ipw_send_cmd-error.txt
+Patch20417: 3009-Added-cmdlog-in-non-debug-systems.txt
+Patch20418: 3010-Migrated-some-of-the-channel-verification-code-back-into-the-driver-to.txt
+Patch20419: 3011-Updated-ipw2200-to-use-the-new-ieee80211-callbacks.txt
+Patch20420: 3012-Added-wait_state-wakeup-on-scan-completion.txt
+Patch20421: 3013-Bug-455-Fix-frequent-channel-change-generates-firmware-fatal-error.txt
+Patch20422: 3014-Bug-760-Fix-setting-WEP-key-in-monitor-mode-causes-IV-lost.txt
+Patch20423: 3015-Don-t-set-hardware-WEP-if-we-are-actually-using-TKIP-AES.txt
+Patch20424: 3016-Make-all-the-places-the-firmware-fails-to-load-showerrors-in-decimal.txt
+Patch20425: 3017-Adds-radiotap-support-to-ipw2200-in-monitor-mode.txt
+Patch20426: 3018-Fixed-is_network_packet-to-include-checking-for-broadcast-packets.txt
+Patch20427: 3019-Mixed-PTK-GTK-CCMP-TKIP-support.txt
+Patch20428: 3020-Card-with-WEP-enabled-and-using-shared-key-auth-will-have-firmware.txt
+Patch20429: 3021-Fixed-problem-with-get_cmd_string-not-existing-if-CONFIG_IPW_DEBUG-disabled.txt
+Patch20430: 3022-Removed-PF_SYNCTHREAD-legacy.txt
+Patch20431: 3023-Fixes-problem-with-WEP-not-working-association-succeeds-but-no-Tx-Rx.txt
+Patch20432: 3024-Fix-bug-771-Too-many-8-bytes-recieved-when-using-AES-hwcrypto.txt
+Patch20433: 3025-Fixes-WEP-firmware-error-condition.txt
+Patch20434: 3026-Updated-driver-version-stamps-for-ipw2100-1.1.3-and-ipw2200-1.0.7.txt
+Patch20435: 3027-Pulled-out-a-stray-KERNEL_VERSION-check-around-the-suspend-handler.txt
+Patch20436: 3028-Fix-Driver-using-old-proc-net-wireless-support-please-fix-driver-message.txt
+Patch20437: 3029-Removed-legacy-WIRELESS_EXT-checks-from-ipw2200.c.txt
+Patch20438: 3030-Fixes-missed-beacon-logic-in-relation-to-on-network-AP-roaming.txt
+Patch20439: 3031-Removed-warning-about-TKIP-not-being-configured-if-countermeasures-are.txt
+Patch20440: 3032-Added-channel-support-for-ipw2200-cards-identified-as-ZZR.txt
+Patch20441: 3033-Fixed-problem-with-not-being-able-to-send-broadcast-packets.txt
+Patch20442: 3034-Fixed-parameter-reordering-in-firmware-log-routine.txt
+Patch20443: 3035-Updated-firmware-version-stamp-to-2.4-from-2.3-so-it-will-use-the-latest-firmware.txt
+Patch20444: 3036-Update-version-ipw2200-stamp-to-1.0.8.txt
+Patch20445: 3074-fix-NET_RADIO-n-IEEE80211-y-compile.txt
+Patch20446: 3075-bonding-fix-feature-consolidation.txt
+Patch20447: 3076-kill-include-linux-eeprom.h.txt
+Patch20448: 3077-drivers-net-s2io.c-make-functions-static.txt
+Patch20449: 3078-prism54-Unused-variable-extraneous-udelay.txt
+Patch20450: 3079-prism54-Transmit-stats-updated-in-wrong-place.txt
+Patch20451: 3080-Fix-sparse-warning-in-e100-driver.txt
+Patch20452: 3081-atmel-memset-correct-range.txt
+Patch20453: 3110-IPV6-Put-addr_diff-into-common-header-for-future-use.txt
+Patch20454: 3111-IPV6-Make-ipv6_addr_type-more-generic-so-that-we-can-use-it-for-source-address-selection.txt
+Patch20455: 3112-IPV6-RFC3484-compliant-source-address-selection.txt
+Patch20456: 3114-PKT_SCHED-Correctly-handle-empty-ematch-trees.txt
+Patch20457: 3115-NET-sk_add_backlog-convert-from-macro-to-inline.txt
+Patch20458: 3117-PPP-handle-misaligned-accesses.txt
+Patch20459: 3118-PPP-add-PPP-MPPE-encryption-module.txt
+Patch20460: 3119-IRDA-donauboe-locking-fix.txt
+Patch20461: 3120-NET-kfree-cleanup.txt
+Patch20462: 3121-IPV4-Fix-ip_queue_xmit-identity-increment-for-TSO-packets.txt
+Patch20463: 3124-Bluetooth-Add-endian-annotations-to-the-core.txt
+Patch20464: 3125-Bluetooth-Remove-the-usage-of-proc-completely.txt
+Patch20465: 3148-SERIAL-IOC3-Update-8250-driver-bits.txt
+Patch20466: 3153-skge-clear-PCI-PHY-COMA-mode-on-boot.txt
+Patch20467: 3154-skge-use-kzalloc.txt
+Patch20468: 3155-skge-add-mii-ioctl-support.txt
+Patch20469: 3156-skge-goto-low-power-mode-on-shutdown.txt
+Patch20470: 3157-skge-use-prefetch-on-receive.txt
+Patch20471: 3158-skge-spelling-fixes.txt
+Patch20472: 3159-skge-increase-version-number.txt
+Patch20473: 3161-wireless-ipw2100-kill-unused-var-warnings-for-debug-disabled-code.txt
+Patch20474: 3162-ieee80211-cleanup-crypto-list-handling-other-minor-cleanups.txt
+Patch20475: 3163-b44-replace-B44_FLAG_INIT_COMPLETE-with-netif_running.txt
+Patch20476: 3164-b44-race-on-device-closing.txt
+Patch20477: 3165-b44-increase-version-number.txt
 Patch20478: 3171-dgrs-fix-warnings-when-CONFIG_ISA-and-CONFIG_PCI-are-not-enabled.txt
 Patch20479: 3172-IOC-And-don-t-mark-the-things-as-broken-Cowboy.txt
 Patch20480: 3224-sanitize-lookup_hash-prototype.txt
@@ -1024,39 +1024,36 @@
 Patch20649: 4570-sky2-remove-pci-express-hacks.txt
 Patch20650: 4571-sky2-use-pci_register_driver.txt
 Patch20651: 4572-sky2-update-version-number.txt
-Patch20652: 4573-sk98lin-fix-checksumming-code.txt
-Patch20653: 4574-sk98lin-add-permanent-address-support.txt
-Patch20654: 4575-sk98lin-avoid-message-confusion-with-skge.txt
-Patch20655: 4576-sk98lin-allow-ethtool-checksum-on-off-per-port.txt
-Patch20656: 4577-sk98lin-remove-redundant-fields-in-device-info.txt
-Patch20657: 4578-sk98lin-remove-proc-interface.txt
-Patch20658: 4579-ibm_emac-fix-graceful-stop-timeout-handling.txt
-Patch20659: 4580-ixp2000-register-netdevices-last.txt
-Patch20660: 4581-pm3386-zero-stats-properly.txt
-Patch20661: 4582-pm3386-remove-unnecessary-udelays.txt
-Patch20662: 4583-caleb-pm3386-include-proper-header-files.txt
-Patch20663: 4584-ixp2000-use-netif_rx_schedule_test.txt
-Patch20664: 4585-enp2611-don-t-check-netif_running-in-link-status-timer.txt
-Patch20665: 4586-enp2611-use-dev-in-link-status-timer.txt
-Patch20666: 4587-enp2611-report-link-up-down-events.txt
-Patch20667: 4588-ixp2000-report-MAC-addresses-for-each-port-on-init.txt
-Patch20668: 4589-pm3386-add-hook-for-setting-MAC-address.txt
-Patch20669: 4590-pm3386-add-hook-for-setting-carrier.txt
-Patch20670: 4591-pm3386-implement-reset.txt
-Patch20671: 4592-enp2611-disable-enable-SERDES-carrier-on-interface-down-up.txt
-Patch20672: 4593-ixp2000-add-netpoll-support.txt
-Patch20673: 4594-ixp2000-add-driver-version-bump-version-to-0.2.txt
-Patch20674: 4595-mipsnet-Fix-Copyright-notice.txt
-Patch20675: 4596-jazzsonic-Fix-build-error.txt
-Patch20676: 4597-jazzsonic-Fix-platform-device-code.txt
-Patch20677: 4598-orinoco-fix-setting-power-management-parameters.txt
-Patch20678: 4599-skge-handle-VLAN-checksum-correctly-on-yukon-rev-0.txt
-Patch20679: 4600-wireless-airo-reset-card-in-init.txt
-Patch20680: 4601-netdrvr-fmvj18x_cs-fix-multicast-bug.txt
-Patch20681: 4602-airo.c-add-support-for-IW_ENCODE_TEMP-i.e.-xsupplicant.txt
-Patch20682: 4603-netdrvr-skge-fix-typo-fix-build.txt
-Patch20683: 4604-ipw2200-kzalloc-conversion-and-Kconfig-dependency-fix.txt
-Patch20684: 4605-Duplicate-IPW_DEBUG-option-for-ipw2100-and-2200.txt
+Patch20652: 4574-sk98lin-add-permanent-address-support.txt
+Patch20653: 4575-sk98lin-avoid-message-confusion-with-skge.txt
+Patch20654: 4577-sk98lin-remove-redundant-fields-in-device-info.txt
+Patch20655: 4579-ibm_emac-fix-graceful-stop-timeout-handling.txt
+Patch20656: 4580-ixp2000-register-netdevices-last.txt
+Patch20657: 4581-pm3386-zero-stats-properly.txt
+Patch20658: 4582-pm3386-remove-unnecessary-udelays.txt
+Patch20659: 4583-caleb-pm3386-include-proper-header-files.txt
+Patch20660: 4584-ixp2000-use-netif_rx_schedule_test.txt
+Patch20661: 4585-enp2611-don-t-check-netif_running-in-link-status-timer.txt
+Patch20662: 4586-enp2611-use-dev-in-link-status-timer.txt
+Patch20663: 4587-enp2611-report-link-up-down-events.txt
+Patch20664: 4588-ixp2000-report-MAC-addresses-for-each-port-on-init.txt
+Patch20665: 4589-pm3386-add-hook-for-setting-MAC-address.txt
+Patch20666: 4590-pm3386-add-hook-for-setting-carrier.txt
+Patch20667: 4591-pm3386-implement-reset.txt
+Patch20668: 4592-enp2611-disable-enable-SERDES-carrier-on-interface-down-up.txt
+Patch20669: 4593-ixp2000-add-netpoll-support.txt
+Patch20670: 4594-ixp2000-add-driver-version-bump-version-to-0.2.txt
+Patch20671: 4595-mipsnet-Fix-Copyright-notice.txt
+Patch20672: 4596-jazzsonic-Fix-build-error.txt
+Patch20673: 4597-jazzsonic-Fix-platform-device-code.txt
+Patch20674: 4598-orinoco-fix-setting-power-management-parameters.txt
+Patch20675: 4599-skge-handle-VLAN-checksum-correctly-on-yukon-rev-0.txt
+Patch20676: 4600-wireless-airo-reset-card-in-init.txt
+Patch20677: 4601-netdrvr-fmvj18x_cs-fix-multicast-bug.txt
+Patch20678: 4602-airo.c-add-support-for-IW_ENCODE_TEMP-i.e.-xsupplicant.txt
+Patch20679: 4603-netdrvr-skge-fix-typo-fix-build.txt
+Patch20680: 4604-ipw2200-kzalloc-conversion-and-Kconfig-dependency-fix.txt
+Patch20681: 4605-Duplicate-IPW_DEBUG-option-for-ipw2100-and-2200.txt
 
 # END OF PATCH DEFINITIONS
 
@@ -1972,111 +1969,111 @@
 %patch20231 -p1
 # sky2: version 0.7
 %patch20232 -p1
-# Input: convert net/bluetooth to dynamic input_dev allocation
-%patch20233 -p1
 # DRIVER MODEL: Get rid of the obsolete tri-level suspend/resume callbacks
+%patch20233 -p1
+# [Bluetooth] Make more functions static
 %patch20234 -p1
-# [Bluetooth] Move CRC table into RFCOMM core
+# [Bluetooth] Update security filter for Extended Inquiry Response
 %patch20235 -p1
-# [Bluetooth] Make more functions static
+# [IPv4/IPv6]: UFO Scatter-gather approach
 %patch20236 -p1
-# [Bluetooth] Update security filter for Extended Inquiry Response
+# [MCAST] IPv6: Fix algorithm to compute Querier's Query Interval
 %patch20237 -p1
-# [IPv4/IPv6]: UFO Scatter-gather approach
+# tg3: add 5714/5715 support
 %patch20238 -p1
-# [MCAST] IPv6: Fix algorithm to compute Querier's Query Interval
+# tg3: fix ASF heartbeat
 %patch20239 -p1
-# tg3: add 5714/5715 support
+# tg3: update version and minor fixes
 %patch20240 -p1
-# tg3: fix ASF heartbeat
+# ibmveth fix bonding
 %patch20241 -p1
-# tg3: update version and minor fixes
+# ibmveth fix buffer pool management
 %patch20242 -p1
-# ibmveth fix bonding
+# ibmveth fix buffer replenishing
 %patch20243 -p1
-# ibmveth fix buffer pool management
+# ibmveth lockless TX
 %patch20244 -p1
-# ibmveth fix buffer replenishing
+# ibmveth fix failed addbuf
 %patch20245 -p1
-# ibmveth lockless TX
+# pcnet_cs: fix mii init code for older DL10019 based cards
 %patch20246 -p1
-# ibmveth fix failed addbuf
+# s2io: kconfig help fix
 %patch20247 -p1
-# pcnet_cs: fix mii init code for older DL10019 based cards
+# b44 reports wrong advertised flags
 %patch20248 -p1
-# s2io: kconfig help fix
+# sis190.c: fix multicast MAC filter
 %patch20249 -p1
-# b44 reports wrong advertised flags
+# smc91x: shut down power after probing
 %patch20250 -p1
-# sis190.c: fix multicast MAC filter
+# starfire: free_irq() on error path of netdev_open()
 %patch20251 -p1
-# smc91x: shut down power after probing
+# [netdrvr b44] include linux/dma-mapping.h to eliminate warning
 %patch20252 -p1
-# starfire: free_irq() on error path of netdev_open()
+# sundance: fix DFE-580TX Tx Underrun
 %patch20253 -p1
-# [netdrvr b44] include linux/dma-mapping.h to eliminate warning
+# New PowerPC 4xx on-chip ethernet controller driver
 %patch20254 -p1
-# sundance: fix DFE-580TX Tx Underrun
+# sis900: come alive after temporary memory shortage
 %patch20255 -p1
-# New PowerPC 4xx on-chip ethernet controller driver
+# Add Wake on LAN support to sis900 (2)
 %patch20256 -p1
-# sis900: come alive after temporary memory shortage
+# drivers/net: Remove pointless checks for NULL prior to calling kfree()
 %patch20257 -p1
-# Add Wake on LAN support to sis900 (2)
+# [netdrvr] ne2k-pci based card does not support bus-mastering.
 %patch20258 -p1
-# drivers/net: Remove pointless checks for NULL prior to calling kfree()
+# ipw2200: Missing kmalloc check
 %patch20259 -p1
-# [netdrvr] ne2k-pci based card does not support bus-mastering.
+# [SCTP] Rename SCTP specific control message flags.
 %patch20260 -p1
-# ipw2200: Missing kmalloc check
+# [SCTP] Fix SCTP_SETADAPTION sockopt to use the correct structure.
 %patch20261 -p1
-# [SCTP] Rename SCTP specific control message flags.
+# [SCTP] Allow SCTP_MAXSEG to revert to default frag point with a '0' value.
 %patch20262 -p1
-# [SCTP] Fix SCTP_SETADAPTION sockopt to use the correct structure.
+# [SCTP] Do not allow unprivileged programs initiating new associations on
 %patch20263 -p1
-# [SCTP] Allow SCTP_MAXSEG to revert to default frag point with a '0' value.
+# e1000: remove warning about e1000_suspend
 %patch20264 -p1
-# [SCTP] Do not allow unprivileged programs initiating new associations on
+# eepro.c: module_param_array cleanup
 %patch20265 -p1
-# e1000: remove warning about e1000_suspend
+# b44: fix suspend/resume
 %patch20266 -p1
-# eepro.c: module_param_array cleanup
+# e1000: use vmalloc_node()
 %patch20267 -p1
-# b44: fix suspend/resume
+# revert "orinoco: Information leakage due to incorrect padding"
 %patch20268 -p1
-# e1000: use vmalloc_node()
+# Better fixup for the orinoco driver
 %patch20269 -p1
-# revert "orinoco: Information leakage due to incorrect padding"
+# e1000: Fixes e1000_suspend warning when CONFIG_PM is not enabled
 %patch20270 -p1
-# Better fixup for the orinoco driver
+# [ETH]: ether address compare
 %patch20271 -p1
-# e1000: Fixes e1000_suspend warning when CONFIG_PM is not enabled
+# Add modalias for pmac network drivers
 %patch20272 -p1
-# [ETH]: ether address compare
+# mv643xx_eth_showsram: Added information message when using the SRAM
 %patch20273 -p1
-# Add modalias for pmac network drivers
+# [IPV4]: Fix issue reported by Coverity in ipv4/fib_frontend.c
 %patch20274 -p1
-# mv643xx_eth_showsram: Added information message when using the SRAM
+# s2io iomem annotations
 %patch20275 -p1
-# [IPV4]: Fix issue reported by Coverity in ipv4/fib_frontend.c
+# bluetooth hidp is broken on s390
 %patch20276 -p1
-# s2io iomem annotations
+# drivers/net/tg3: Use the DMA_{32,64}BIT_MASK constants
 %patch20277 -p1
-# bluetooth hidp is broken on s390
+# prism54: Free skb after disabling interrupts
 %patch20278 -p1
-# drivers/net/tg3: Use the DMA_{32,64}BIT_MASK constants
+# [DRIVER MODEL] Add missing platform_device.h header.
 %patch20279 -p1
-# prism54: Free skb after disabling interrupts
-%patch20280 -p1
 # PPC 44x EMAC driver: add 440SPe support
-%patch20281 -p1
+%patch20280 -p1
 # PPC 44x EMAC driver: add 440GR support
-%patch20282 -p1
+%patch20281 -p1
 # PPC 4xx EMAC driver: fix VSC8201 PHY initialization
-%patch20283 -p1
+%patch20282 -p1
 # fec_8xx: Remove dependency on NETTA & NETPHONE
-%patch20284 -p1
+%patch20283 -p1
 # fec_8xx: Add support for Intel PHY LX971
+%patch20284 -p1
+# vmalloc_node
 %patch20285 -p1
 # [ARM] 3066/1: Fix PXA irda driver suspend/resume functions
 %patch20286 -p1
@@ -2198,269 +2195,269 @@
 %patch20344 -p1
 # [PKT_SCHED]: (G)RED: Introduce hard dropping
 %patch20345 -p1
-# [DRIVER MODEL] Fix depca
+# [DRIVER MODEL] Improved dynamically allocated platform_device interface
 %patch20346 -p1
-# [DRIVER MODEL] Fix jazzsonic
+# [DRIVER MODEL] Fix depca
 %patch20347 -p1
-# [DRIVER MODEL] Fix macsonic
+# [DRIVER MODEL] Fix jazzsonic
 %patch20348 -p1
-# [NETEM]: Support time based reordering
+# [DRIVER MODEL] Fix macsonic
 %patch20349 -p1
-# [NETEM]: Add version string
+# [NETEM]: Support time based reordering
 %patch20350 -p1
-# [NET]: Fix race condition in sk_stream_wait_connect
+# [NETEM]: Add version string
 %patch20351 -p1
-# [TCP/DCCP]: Randomize port selection
+# [NET]: Fix race condition in sk_stream_wait_connect
 %patch20352 -p1
-# drivers/net/ixgb/: make some code static
+# [TCP/DCCP]: Randomize port selection
 %patch20353 -p1
-# drivers/net/e1000/: possible cleanups
+# drivers/net/ixgb/: make some code static
 %patch20354 -p1
-# drivers/net/hamradio/dmascc.c: remove dmascc_setup()
+# drivers/net/e1000/: possible cleanups
 %patch20355 -p1
-# prism54: Remove redundant assignment
+# drivers/net/hamradio/dmascc.c: remove dmascc_setup()
 %patch20356 -p1
-# bnx2: add 5708 support
+# prism54: Remove redundant assignment
 %patch20357 -p1
-# bnx2: update firmware for 5708
+# bnx2: add 5708 support
 %patch20358 -p1
-# bnx2: update nvram code for 5708
+# bnx2: update firmware for 5708
 %patch20359 -p1
-# bnx2: update firmware handshake for 5708
+# bnx2: update nvram code for 5708
 %patch20360 -p1
-# bnx2: refine bnx2_poll
+# bnx2: update firmware handshake for 5708
 %patch20361 -p1
-# bnx2: update version and minor fixes
+# bnx2: refine bnx2_poll
 %patch20362 -p1
-# Remove linux/version.h include from drivers/net/phy/\1 and net/ieee80211/\1.
+# bnx2: update version and minor fixes
 %patch20363 -p1
-# [netdrvr] fac_8xx build fix
+# Remove linux/version.h include from drivers/net/phy/\1 and net/ieee80211/\1.
 %patch20364 -p1
-# [netdrvr s2io] warning fixes
+# [netdrvr] fac_8xx build fix
 %patch20365 -p1
-# b44: b44_start_xmit returns with a lock held when it fails allocating
+# [netdrvr s2io] warning fixes
 %patch20366 -p1
-# b44: miscellaneous cleanup
+# b44: b44_start_xmit returns with a lock held when it fails allocating
 %patch20367 -p1
-# b44: expose counters through ethtool
+# b44: miscellaneous cleanup
 %patch20368 -p1
-# b44: s/spin_lock_irqsave/spin_lock/ in b44_interrupt
+# b44: expose counters through ethtool
 %patch20369 -p1
-# b44: late request_irq in b44_open
+# b44: s/spin_lock_irqsave/spin_lock/ in b44_interrupt
 %patch20370 -p1
-# 3c59x: convert to use of pci_iomap API
+# b44: late request_irq in b44_open
 %patch20371 -p1
-# 3c59x: cleanup of mdio_read routines to use MII_\1 macros
+# 3c59x: convert to use of pci_iomap API
 %patch20372 -p1
-# 3c59x: avoid blindly reading link status twice
+# 3c59x: cleanup of mdio_read routines to use MII_\1 macros
 %patch20373 -p1
-# 3c59x: bounds checking for hw_checksums
+# 3c59x: avoid blindly reading link status twice
 %patch20374 -p1
-# 3c59x: cleanup init of module parameter arrays
+# 3c59x: bounds checking for hw_checksums
 %patch20375 -p1
-# 3c59x: fix some grammar in module parameter descriptions
+# 3c59x: cleanup init of module parameter arrays
 %patch20376 -p1
-# 3c59x: support ETHTOOL_GPERMADDR
+# 3c59x: fix some grammar in module parameter descriptions
 %patch20377 -p1
-# 3c59x: correct rx_dropped counting
+# 3c59x: support ETHTOOL_GPERMADDR
 %patch20378 -p1
-# 3c59x: enable use of memory-mapped PCI I/O
+# 3c59x: correct rx_dropped counting
 %patch20379 -p1
-# 3c59x: don't enable scatter/gather w/o checksum support
+# 3c59x: enable use of memory-mapped PCI I/O
 %patch20380 -p1
-# knfsd: make sure svc_process call the correct pg_authenticate for multi-service port
+# 3c59x: don't enable scatter/gather w/o checksum support
 %patch20381 -p1
-# m68knommu: FEC ethernet header support for the ColdFire 5208
+# knfsd: make sure svc_process call the correct pg_authenticate for multi-service port
 %patch20382 -p1
-# m68knommu: FEC ethernet support for the ColdFire 5208
+# m68knommu: FEC ethernet header support for the ColdFire 5208
 %patch20383 -p1
-# scripts/Lindent on ieee80211 subsystem.
+# m68knommu: FEC ethernet support for the ColdFire 5208
 %patch20384 -p1
-# Fix problem with WEP unicast key > index 0
+# scripts/Lindent on ieee80211 subsystem.
 %patch20385 -p1
-# Update version ieee80211 stamp to 1.1.7
+# Fix problem with WEP unicast key > index 0
 %patch20386 -p1
-# Ran scripts/Lindent on drivers/net/wireless/ipw2{1,2}00.{c,h}
+# Update version ieee80211 stamp to 1.1.7
 %patch20387 -p1
-# IPW_DEBUG has already included DRV_NAME, remove double prefix print.
+# Ran scripts/Lindent on drivers/net/wireless/ipw2{1,2}00.{c,h}
 %patch20388 -p1
-# Catch ipw2200 up to equivelancy with v1.0.1
+# IPW_DEBUG has already included DRV_NAME, remove double prefix print.
 %patch20389 -p1
-# Catch ipw2200 up to equivelancy with v1.0.2
+# Catch ipw2200 up to equivelancy with v1.0.1
 %patch20390 -p1
-# Catch ipw2200 up to equivelancy with v1.0.3
+# Catch ipw2200 up to equivelancy with v1.0.2
 %patch20391 -p1
-# Catch ipw2200 up to equivelancy with v1.0.4
+# Catch ipw2200 up to equivelancy with v1.0.3
 %patch20392 -p1
-# Catch ipw2100 up to equivelancy with v1.1.1
+# Catch ipw2200 up to equivelancy with v1.0.4
 %patch20393 -p1
-# Fixed WEP on ipw2100 (priv->sec was being used instead of
+# Catch ipw2100 up to equivelancy with v1.1.1
 %patch20394 -p1
-# [Bug 339] Fix ipw2100 iwconfig set/get txpower.
+# Fixed WEP on ipw2100 (priv->sec was being used instead of
 %patch20395 -p1
-# Move code from ipw2100_wpa_enable to IPW2100_PARAM_DROP_UNENCRYPTED to
+# [Bug 339] Fix ipw2100 iwconfig set/get txpower.
 %patch20396 -p1
-# Catch ipw2200 up to equivelancy with v1.0.5
+# Move code from ipw2100_wpa_enable to IPW2100_PARAM_DROP_UNENCRYPTED to
 %patch20397 -p1
-# Fix hardware encryption (both WEP and AES) doesn't work with fragmentation.
+# Catch ipw2200 up to equivelancy with v1.0.5
 %patch20398 -p1
-# Fix is_duplicate_packet() bug for fragmentation number setting.
+# Fix hardware encryption (both WEP and AES) doesn't work with fragmentation.
 %patch20399 -p1
-# [bug 667] Fix the notorious "No space for Tx" bug.
+# Fix is_duplicate_packet() bug for fragmentation number setting.
 %patch20400 -p1
-# [Bug 637] Set tx power for A band.
+# [bug 667] Fix the notorious "No space for Tx" bug.
 %patch20401 -p1
-# Changed default # of missed beacons to miss before disassociation to 24
+# [Bug 637] Set tx power for A band.
 %patch20402 -p1
-# Updated to support ieee80211 callback to is_queue_full for 802.11e
+# Changed default # of missed beacons to miss before disassociation to 24
 %patch20403 -p1
-# Fixed some compiler issues if CONFIG_IPW2200_QOS is enabled.
+# Updated to support ieee80211 callback to is_queue_full for 802.11e
 %patch20404 -p1
-# Added more useful geography encoding so people's experience with
+# Fixed some compiler issues if CONFIG_IPW2200_QOS is enabled.
 %patch20405 -p1
-# Workaround kernel BUG_ON panic caused by unexpected duplicate packets.
+# Added more useful geography encoding so people's experience with
 %patch20406 -p1
-# Disable host fragmentation in open mode since IPW2200/2915 hardware
+# Workaround kernel BUG_ON panic caused by unexpected duplicate packets.
 %patch20407 -p1
-# [Bug 792] Fix WPA-PSK AES both for -Dipw and -Dwext.
+# Disable host fragmentation in open mode since IPW2200/2915 hardware
 %patch20408 -p1
-# Fixes the ad-hoc network WEP key list issue.
+# [Bug 792] Fix WPA-PSK AES both for -Dipw and -Dwext.
 %patch20409 -p1
-# [Bug 701] Fix a misuse of ieee->mode with ieee->iw_mode.
+# Fixes the ad-hoc network WEP key list issue.
 %patch20410 -p1
-# Fix ipw_wx_get_txpow shows wrong disabled value.
+# [Bug 701] Fix a misuse of ieee->mode with ieee->iw_mode.
 %patch20411 -p1
-# Fix firmware error when setting tx_power.
+# Fix ipw_wx_get_txpow shows wrong disabled value.
 %patch20412 -p1
-# Modified ipw_config and STATUS_INIT setting to correct race condition
+# Fix firmware error when setting tx_power.
 %patch20413 -p1
-# Switched firmware error dumping so that it will capture a log available
+# Modified ipw_config and STATUS_INIT setting to correct race condition
 %patch20414 -p1
-# Changed all of the ipw_send_cmd() calls to return any ipw_send_cmd error
+# Switched firmware error dumping so that it will capture a log available
 %patch20415 -p1
-# Added cmdlog in non-debug systems.
+# Changed all of the ipw_send_cmd() calls to return any ipw_send_cmd error
 %patch20416 -p1
-# Migrated some of the channel verification code back into the driver to
+# Added cmdlog in non-debug systems.
 %patch20417 -p1
-# Updated ipw2200 to use the new ieee80211 callbacks
+# Migrated some of the channel verification code back into the driver to
 %patch20418 -p1
-# Added wait_state wakeup on scan completion.
+# Updated ipw2200 to use the new ieee80211 callbacks
 %patch20419 -p1
-# [Bug 455] Fix frequent channel change generates firmware fatal error.
+# Added wait_state wakeup on scan completion.
 %patch20420 -p1
-# [Bug 760] Fix setting WEP key in monitor mode causes IV lost.
+# [Bug 455] Fix frequent channel change generates firmware fatal error.
 %patch20421 -p1
-# Don't set hardware WEP if we are actually using TKIP/AES.
+# [Bug 760] Fix setting WEP key in monitor mode causes IV lost.
 %patch20422 -p1
-# Make all the places the firmware fails to load showerrors (in decimal,
+# Don't set hardware WEP if we are actually using TKIP/AES.
 %patch20423 -p1
-# Adds radiotap support to ipw2200 in monitor mode..
+# Make all the places the firmware fails to load showerrors (in decimal,
 %patch20424 -p1
-# Fixed is_network_packet() to include checking for broadcast packets.
+# Adds radiotap support to ipw2200 in monitor mode..
 %patch20425 -p1
-# Mixed PTK/GTK CCMP/TKIP support.
+# Fixed is_network_packet() to include checking for broadcast packets.
 %patch20426 -p1
-# Card with WEP enabled and using shared-key auth will have firmware
+# Mixed PTK/GTK CCMP/TKIP support.
 %patch20427 -p1
-# Fixed problem with get_cmd_string not existing if CONFIG_IPW_DEBUG disabled.
+# Card with WEP enabled and using shared-key auth will have firmware
 %patch20428 -p1
-# Removed PF_SYNCTHREAD legacy.
+# Fixed problem with get_cmd_string not existing if CONFIG_IPW_DEBUG disabled.
 %patch20429 -p1
-# Fixes problem with WEP not working (association succeeds, but no Tx/Rx)
+# Removed PF_SYNCTHREAD legacy.
 %patch20430 -p1
-# [Fix bug# 771] Too many (8) bytes recieved when using AES/hwcrypto
+# Fixes problem with WEP not working (association succeeds, but no Tx/Rx)
 %patch20431 -p1
-# Fixes WEP firmware error condition.
+# [Fix bug# 771] Too many (8) bytes recieved when using AES/hwcrypto
 %patch20432 -p1
-# Updated driver version stamps for ipw2100 (1.1.3) and ipw2200 (1.0.7)
+# Fixes WEP firmware error condition.
 %patch20433 -p1
-# Pulled out a stray KERNEL_VERSION check around the suspend handler.
+# Updated driver version stamps for ipw2100 (1.1.3) and ipw2200 (1.0.7)
 %patch20434 -p1
-# Fix 'Driver using old /proc/net/wireless support, please fix driver !' message.
+# Pulled out a stray KERNEL_VERSION check around the suspend handler.
 %patch20435 -p1
-# Removed legacy WIRELESS_EXT checks from ipw2200.c
+# Fix 'Driver using old /proc/net/wireless support, please fix driver !' message.
 %patch20436 -p1
-# Fixes missed beacon logic in relation to on-network AP roaming.
+# Removed legacy WIRELESS_EXT checks from ipw2200.c
 %patch20437 -p1
-# Removed warning about TKIP not being configured if countermeasures are
+# Fixes missed beacon logic in relation to on-network AP roaming.
 %patch20438 -p1
-# Added channel support for ipw2200 cards identified as 'ZZR'
+# Removed warning about TKIP not being configured if countermeasures are
 %patch20439 -p1
-# Fixed problem with not being able to send broadcast packets.
+# Added channel support for ipw2200 cards identified as 'ZZR'
 %patch20440 -p1
-# Fixed parameter reordering in firmware log routine.
+# Fixed problem with not being able to send broadcast packets.
 %patch20441 -p1
-# Updated firmware version stamp to 2.4 from 2.3 so it will use the latest firmware.
+# Fixed parameter reordering in firmware log routine.
 %patch20442 -p1
-# Update version ipw2200 stamp to 1.0.8
+# Updated firmware version stamp to 2.4 from 2.3 so it will use the latest firmware.
 %patch20443 -p1
-# fix NET_RADIO=n, IEEE80211=y compile
+# Update version ipw2200 stamp to 1.0.8
 %patch20444 -p1
-# bonding: fix feature consolidation
+# fix NET_RADIO=n, IEEE80211=y compile
 %patch20445 -p1
-# kill include/linux/eeprom.h
+# bonding: fix feature consolidation
 %patch20446 -p1
-# drivers/net/s2io.c: make functions static
+# kill include/linux/eeprom.h
 %patch20447 -p1
-# prism54 : Unused variable / extraneous udelay
+# drivers/net/s2io.c: make functions static
 %patch20448 -p1
-# prism54 : Transmit stats updated in wrong place
+# prism54 : Unused variable / extraneous udelay
 %patch20449 -p1
-# Fix sparse warning in e100 driver.
+# prism54 : Transmit stats updated in wrong place
 %patch20450 -p1
-# atmel: memset correct range
+# Fix sparse warning in e100 driver.
 %patch20451 -p1
-# [IPV6]: Put addr_diff() into common header for future use.
+# atmel: memset correct range
 %patch20452 -p1
-# [IPV6]: Make ipv6_addr_type() more generic so that we can use it for source address selection.
+# [IPV6]: Put addr_diff() into common header for future use.
 %patch20453 -p1
-# [IPV6]: RFC3484 compliant source address selection
+# [IPV6]: Make ipv6_addr_type() more generic so that we can use it for source address selection.
 %patch20454 -p1
-# [PKT_SCHED]: Correctly handle empty ematch trees
+# [IPV6]: RFC3484 compliant source address selection
 %patch20455 -p1
-# [NET]: sk_add_backlog convert from macro to inline
+# [PKT_SCHED]: Correctly handle empty ematch trees
 %patch20456 -p1
-# [PPP]: handle misaligned accesses
+# [NET]: sk_add_backlog convert from macro to inline
 %patch20457 -p1
-# [PPP]: add PPP MPPE encryption module
+# [PPP]: handle misaligned accesses
 %patch20458 -p1
-# [IRDA] donauboe: locking fix
+# [PPP]: add PPP MPPE encryption module
 %patch20459 -p1
-# [NET]: kfree cleanup
+# [IRDA] donauboe: locking fix
 %patch20460 -p1
-# [IPV4]: Fix ip_queue_xmit identity increment for TSO packets
+# [NET]: kfree cleanup
 %patch20461 -p1
-# [Bluetooth]: Add endian annotations to the core
+# [IPV4]: Fix ip_queue_xmit identity increment for TSO packets
 %patch20462 -p1
-# [Bluetooth]: Remove the usage of /proc completely
+# [Bluetooth]: Add endian annotations to the core
 %patch20463 -p1
-# [SERIAL] IOC3: Update 8250 driver bits
+# [Bluetooth]: Remove the usage of /proc completely
 %patch20464 -p1
-# skge: clear PCI PHY COMA mode on boot
+# [SERIAL] IOC3: Update 8250 driver bits
 %patch20465 -p1
-# skge: use kzalloc
+# skge: clear PCI PHY COMA mode on boot
 %patch20466 -p1
-# skge: add mii ioctl support
+# skge: use kzalloc
 %patch20467 -p1
-# skge: goto low power mode on shutdown
+# skge: add mii ioctl support
 %patch20468 -p1
-# skge: use prefetch on receive
+# skge: goto low power mode on shutdown
 %patch20469 -p1
-# skge: spelling fixes
+# skge: use prefetch on receive
 %patch20470 -p1
-# skge: increase version number
+# skge: spelling fixes
 %patch20471 -p1
-# [wireless ipw2100] kill unused-var warnings for debug-disabled code
+# skge: increase version number
 %patch20472 -p1
-# ieee80211: cleanup crypto list handling, other minor cleanups.
+# [wireless ipw2100] kill unused-var warnings for debug-disabled code
 %patch20473 -p1
-# b44: replace B44_FLAG_INIT_COMPLETE with netif_running()
+# ieee80211: cleanup crypto list handling, other minor cleanups.
 %patch20474 -p1
-# b44: race on device closing
+# b44: replace B44_FLAG_INIT_COMPLETE with netif_running()
 %patch20475 -p1
-# b44: increase version number
+# b44: race on device closing
 %patch20476 -p1
-# cris v10 eth: use ethtool_ops
+# b44: increase version number
 %patch20477 -p1
 # dgrs: fix warnings when CONFIG_ISA and CONFIG_PCI are not enabled
 %patch20478 -p1
@@ -2810,72 +2807,66 @@
 %patch20650 -p1
 # sky2: update version number
 %patch20651 -p1
-# sk98lin: fix checksumming code
-%patch20652 -p1
 # sk98lin: add permanent address support
-%patch20653 -p1
+%patch20652 -p1
 # sk98lin: avoid message confusion with skge
-%patch20654 -p1
-# sk98lin: allow ethtool checksum on/off per port
-%patch20655 -p1
+%patch20653 -p1
 # sk98lin: remove redundant fields in device info
-%patch20656 -p1
-# sk98lin: remove /proc interface
-%patch20657 -p1
+%patch20654 -p1
 # ibm_emac: fix graceful stop timeout handling
-%patch20658 -p1
+%patch20655 -p1
 # ixp2000: register netdevices last
-%patch20659 -p1
+%patch20656 -p1
 # pm3386: zero stats properly
-%patch20660 -p1
+%patch20657 -p1
 # pm3386: remove unnecessary udelays
-%patch20661 -p1
+%patch20658 -p1
 # caleb/pm3386: include proper header files
-%patch20662 -p1
+%patch20659 -p1
 # ixp2000: use netif_rx_schedule_test
-%patch20663 -p1
+%patch20660 -p1
 # enp2611: don't check netif_running() in link status timer
-%patch20664 -p1
+%patch20661 -p1
 # enp2611: use 'dev' in link status timer
-%patch20665 -p1
+%patch20662 -p1
 # enp2611: report link up/down events
-%patch20666 -p1
+%patch20663 -p1
 # ixp2000: report MAC addresses for each port on init
-%patch20667 -p1
+%patch20664 -p1
 # pm3386: add hook for setting MAC address
-%patch20668 -p1
+%patch20665 -p1
 # pm3386: add hook for setting carrier
-%patch20669 -p1
+%patch20666 -p1
 # pm3386: implement reset
-%patch20670 -p1
+%patch20667 -p1
 # enp2611: disable/enable SERDES carrier on interface down/up
-%patch20671 -p1
+%patch20668 -p1
 # ixp2000: add netpoll support
-%patch20672 -p1
+%patch20669 -p1
 # ixp2000: add driver version, bump version to 0.2
-%patch20673 -p1
+%patch20670 -p1
 # mipsnet: Fix Copyright notice.
-%patch20674 -p1
+%patch20671 -p1
 # jazzsonic: Fix build error.
-%patch20675 -p1
+%patch20672 -p1
 # jazzsonic: Fix platform device code
-%patch20676 -p1
+%patch20673 -p1
 # orinoco: fix setting power management parameters
-%patch20677 -p1
+%patch20674 -p1
 # skge: handle VLAN checksum correctly on yukon rev 0
-%patch20678 -p1
+%patch20675 -p1
 # [wireless airo] reset card in init
-%patch20679 -p1
+%patch20676 -p1
 # [netdrvr fmvj18x_cs] fix multicast bug
-%patch20680 -p1
+%patch20677 -p1
 # airo.c: add support for IW_ENCODE_TEMP (i.e. xsupplicant)
-%patch20681 -p1
+%patch20678 -p1
 # [netdrvr skge] fix typo, fix build
-%patch20682 -p1
+%patch20679 -p1
 # ipw2200: kzalloc conversion and Kconfig dependency fix
-%patch20683 -p1
+%patch20680 -p1
 # Duplicate IPW_DEBUG option for ipw2100 and 2200
-%patch20684 -p1
+%patch20681 -p1
 
 #
 # final stuff
@@ -3547,9 +3538,7 @@
 - sky2: spelling fixes
 - sky2: fix NAPI and receive handling
 - sky2: version 0.7
-- Input: convert net/bluetooth to dynamic input_dev allocation
 - DRIVER MODEL: Get rid of the obsolete tri-level suspend/resume callbacks
-- [Bluetooth] Move CRC table into RFCOMM core
 - [Bluetooth] Make more functions static
 - [Bluetooth] Update security filter for Extended Inquiry Response
 - [IPv4/IPv6]: UFO Scatter-gather approach
@@ -3595,11 +3584,13 @@
 - bluetooth hidp is broken on s390
 - drivers/net/tg3: Use the DMA_{32,64}BIT_MASK constants
 - prism54: Free skb after disabling interrupts
+- [DRIVER MODEL] Add missing platform_device.h header.
 - PPC 44x EMAC driver: add 440SPe support
 - PPC 44x EMAC driver: add 440GR support
 - PPC 4xx EMAC driver: fix VSC8201 PHY initialization
 - fec_8xx: Remove dependency on NETTA & NETPHONE
 - fec_8xx: Add support for Intel PHY LX971
+- vmalloc_node
 - [ARM] 3066/1: Fix PXA irda driver suspend/resume functions
 - m32r: SMC91x driver update
 - smsc-ircc2: PM cleanup - do not close device when suspending
@@ -3660,6 +3651,7 @@
 - [PKT_SCHED]: GRED: Fix restart of idle period in WRED mode upon dequeue and drop
 - [PKT_SCHED]: GRED: Support ECN marking
 - [PKT_SCHED]: (G)RED: Introduce hard dropping
+- [DRIVER MODEL] Improved dynamically allocated platform_device interface
 - [DRIVER MODEL] Fix depca
 - [DRIVER MODEL] Fix jazzsonic
 - [DRIVER MODEL] Fix macsonic
@@ -3791,7 +3783,6 @@
 - b44: replace B44_FLAG_INIT_COMPLETE with netif_running()
 - b44: race on device closing
 - b44: increase version number
-- cris v10 eth: use ethtool_ops
 - dgrs: fix warnings when CONFIG_ISA and CONFIG_PCI are not enabled
 - IOC: And don't mark the things as broken Cowboy.
 - sanitize lookup_hash prototype
@@ -3966,12 +3957,9 @@
 - sky2: remove pci-express hacks
 - sky2: use pci_register_driver
 - sky2: update version number
-- sk98lin: fix checksumming code
 - sk98lin: add permanent address support
 - sk98lin: avoid message confusion with skge
-- sk98lin: allow ethtool checksum on/off per port
 - sk98lin: remove redundant fields in device info
-- sk98lin: remove /proc interface
 - ibm_emac: fix graceful stop timeout handling
 - ixp2000: register netdevices last
 - pm3386: zero stats properly


--- 1014-Input-convert-net-bluetooth-to-dynamic-input_dev-allocation.txt DELETED ---


--- 1034-Bluetooth-Move-CRC-table-into-RFCOMM-core.txt DELETED ---


--- 3166-cris-v10-eth-use-ethtool_ops.txt DELETED ---


--- 4573-sk98lin-fix-checksumming-code.txt DELETED ---


--- 4576-sk98lin-allow-ethtool-checksum-on-off-per-port.txt DELETED ---


--- 4578-sk98lin-remove-proc-interface.txt DELETED ---




More information about the fedora-cvs-commits mailing list
diff --git a/mm/vmalloc.c b/mm/vmalloc.c
index 1150229..5e91205 100644
--- a/mm/vmalloc.c
+++ b/mm/vmalloc.c
@@ -5,6 +5,7 @@
  *  Support of BIGMEM added by Gerhard Wichert, Siemens AG, July 1999
  *  SMP-safe vmalloc/vfree/ioremap, Tigran Aivazian <tigran at veritas.com>, May 2000
  *  Major rework to support vmap/vunmap, Christoph Hellwig, SGI, August 2002
+ *  Numa awareness, Christoph Lameter, SGI, June 2005
  */
 
 #include <linux/mm.h>
@@ -158,8 +159,8 @@ int map_vm_area(struct vm_struct *area, 
 	return err;
 }
 
-struct vm_struct *__get_vm_area(unsigned long size, unsigned long flags,
-				unsigned long start, unsigned long end)
+struct vm_struct *__get_vm_area_node(unsigned long size, unsigned long flags,
+				unsigned long start, unsigned long end, int node)
 {
 	struct vm_struct **p, *tmp, *area;
 	unsigned long align = 1;
@@ -178,7 +179,7 @@ struct vm_struct *__get_vm_area(unsigned
 	addr = ALIGN(start, align);
 	size = PAGE_ALIGN(size);
 
-	area = kmalloc(sizeof(*area), GFP_KERNEL);
+	area = kmalloc_node(sizeof(*area), GFP_KERNEL, node);
 	if (unlikely(!area))
 		return NULL;
 
@@ -231,6 +232,12 @@ out:
 	return NULL;
 }
 
+struct vm_struct *__get_vm_area(unsigned long size, unsigned long flags,
+				unsigned long start, unsigned long end)
+{
+	return __get_vm_area_node(size, flags, start, end, -1);
+}
+
 /**
  *	get_vm_area  -  reserve a contingous kernel virtual area
  *
@@ -246,6 +253,11 @@ struct vm_struct *get_vm_area(unsigned l
 	return __get_vm_area(size, flags, VMALLOC_START, VMALLOC_END);
 }
 
+struct vm_struct *get_vm_area_node(unsigned long size, unsigned long flags, int node)
+{
+	return __get_vm_area_node(size, flags, VMALLOC_START, VMALLOC_END, node);
+}
+
 /* Caller must hold vmlist_lock */
 struct vm_struct *__remove_vm_area(void *addr)
 {
@@ -342,7 +354,6 @@ void vfree(void *addr)
 	BUG_ON(in_interrupt());
 	__vunmap(addr, 1);
 }
-
 EXPORT_SYMBOL(vfree);
 
 /**
@@ -360,7 +371,6 @@ void vunmap(void *addr)
 	BUG_ON(in_interrupt());
 	__vunmap(addr, 0);
 }
-
 EXPORT_SYMBOL(vunmap);
 
 /**
@@ -392,10 +402,10 @@ void *vmap(struct page **pages, unsigned
 
 	return area->addr;
 }
-
 EXPORT_SYMBOL(vmap);
 
-void *__vmalloc_area(struct vm_struct *area, gfp_t gfp_mask, pgprot_t prot)
+void *__vmalloc_area_node(struct vm_struct *area, gfp_t gfp_mask,
+				pgprot_t prot, int node)
 {
 	struct page **pages;
 	unsigned int nr_pages, array_size, i;
@@ -406,9 +416,9 @@ void *__vmalloc_area(struct vm_struct *a
 	area->nr_pages = nr_pages;
 	/* Please note that the recursion is strictly bounded. */
 	if (array_size > PAGE_SIZE)
-		pages = __vmalloc(array_size, gfp_mask, PAGE_KERNEL);
+		pages = __vmalloc_node(array_size, gfp_mask, PAGE_KERNEL, node);
 	else
-		pages = kmalloc(array_size, (gfp_mask & ~__GFP_HIGHMEM));
+		pages = kmalloc_node(array_size, (gfp_mask & ~__GFP_HIGHMEM), node);
 	area->pages = pages;
 	if (!area->pages) {
 		remove_vm_area(area->addr);
@@ -418,7 +428,10 @@ void *__vmalloc_area(struct vm_struct *a
 	memset(area->pages, 0, array_size);
 
 	for (i = 0; i < area->nr_pages; i++) {
-		area->pages[i] = alloc_page(gfp_mask);
+		if (node < 0)
+			area->pages[i] = alloc_page(gfp_mask);
+		else
+			area->pages[i] = alloc_pages_node(node, gfp_mask, 0);
 		if (unlikely(!area->pages[i])) {
 			/* Successfully allocated i pages, free them in __vunmap() */
 			area->nr_pages = i;
@@ -435,18 +448,25 @@ fail:
 	return NULL;
 }
 
+void *__vmalloc_area(struct vm_struct *area, gfp_t gfp_mask, pgprot_t prot)
+{
+	return __vmalloc_area_node(area, gfp_mask, prot, -1);
+}
+
 /**
  *	__vmalloc  -  allocate virtually contiguous memory
  *
  *	@size:		allocation size
  *	@gfp_mask:	flags for the page level allocator
  *	@prot:		protection mask for the allocated pages
+ *	@node		node to use for allocation or -1
  *
  *	Allocate enough pages to cover @size from the page level
  *	allocator with @gfp_mask flags.  Map them into contiguous
  *	kernel virtual space, using a pagetable protection of @prot.
  */
-void *__vmalloc(unsigned long size, gfp_t gfp_mask, pgprot_t prot)
+void *__vmalloc_node(unsigned long size, gfp_t gfp_mask, pgprot_t prot,
+			int node)
 {
 	struct vm_struct *area;
 
@@ -454,13 +474,18 @@ void *__vmalloc(unsigned long size, gfp_
 	if (!size || (size >> PAGE_SHIFT) > num_physpages)
 		return NULL;
 
-	area = get_vm_area(size, VM_ALLOC);
+	area = get_vm_area_node(size, VM_ALLOC, node);
 	if (!area)
 		return NULL;
 
-	return __vmalloc_area(area, gfp_mask, prot);
+	return __vmalloc_area_node(area, gfp_mask, prot, node);
 }
+EXPORT_SYMBOL(__vmalloc_node);
 
+void *__vmalloc(unsigned long size, gfp_t gfp_mask, pgprot_t prot)
+{
+	return __vmalloc_node(size, gfp_mask, prot, -1);
+}
 EXPORT_SYMBOL(__vmalloc);
 
 /**
@@ -478,9 +503,26 @@ void *vmalloc(unsigned long size)
 {
        return __vmalloc(size, GFP_KERNEL | __GFP_HIGHMEM, PAGE_KERNEL);
 }
-
 EXPORT_SYMBOL(vmalloc);
 
+/**
+ *	vmalloc_node  -  allocate memory on a specific node
+ *
+ *	@size:		allocation size
+ *	@node;		numa node
+ *
+ *	Allocate enough pages to cover @size from the page level
+ *	allocator and map them into contiguous kernel virtual space.
+ *
+ *	For tight cotrol over page level allocator and protection flags
+ *	use __vmalloc() instead.
+ */
+void *vmalloc_node(unsigned long size, int node)
+{
+       return __vmalloc_node(size, GFP_KERNEL | __GFP_HIGHMEM, PAGE_KERNEL, node);
+}
+EXPORT_SYMBOL(vmalloc_node);
+
 #ifndef PAGE_KERNEL_EXEC
 # define PAGE_KERNEL_EXEC PAGE_KERNEL
 #endif
@@ -515,7 +557,6 @@ void *vmalloc_32(unsigned long size)
 {
 	return __vmalloc(size, GFP_KERNEL, PAGE_KERNEL);
 }
-
 EXPORT_SYMBOL(vmalloc_32);
 
 long vread(char *buf, char *addr, unsigned long count)
---
0.99.8.GIT


--- NEW FILE 2468-DRIVER-MODEL-Improved-dynamically-allocated-platform_device-interface.txt ---
Subject: [PATCH] [DRIVER MODEL] Improved dynamically allocated platform_device interface
From: Russell King <rmk at dyn-67.arm.linux.org.uk>
Date: 1131225573 +0000

Re-jig the simple platform device support to allow private data
to be attached to a platform device, as well as allowing the
parent device to be set.

Example usage:

	pdev = platform_device_alloc("mydev", id);
	if (pdev) {
		err = platform_device_add_resources(pdev, &resources,
						    ARRAY_SIZE(resources));
		if (err == 0)
			err = platform_device_add_data(pdev, &platform_data,
						       sizeof(platform_data));
		if (err == 0)
			err = platform_device_add(pdev);
	} else {
		err = -ENOMEM;
	}
	if (err)
		platform_device_put(pdev);

Signed-off-by: Russell King <rmk+kernel at arm.linux.org.uk>
Acked-by: Greg Kroah-Hartman <gregkh at suse.de>

---

 drivers/base/platform.c         |  153 ++++++++++++++++++++++++++++++++-------
 include/linux/platform_device.h |    6 ++
@@ -435,18 +448,25 @@ fail:
 /**
- *	__vmalloc  -  allocate virtually contiguous memory
+ *	__vmalloc_node  -  allocate virtually contiguous memory
  *
  *	@size:		allocation size
 2 files changed, 132 insertions(+), 27 deletions(-)

applies-to: c403b29783de27e290b5d12f12054d03f96ce8b2
37c12e7497b6fe2b6a890814f0ff4edce696d862